###############################################################################
# Only execute commands if file was not included already
###############################################################################
if (NOT GOING_IMMERSIVE_CONFIG_CMAKE_LOADED)


###############################################################################
# Initialize boolean values for TrackD and VRPN support
###############################################################################
if (NOT ENABLE_TRACKD_SUPPORT)
  set (ENABLE_TRACKD_SUPPORT OFF
  	CACHE BOOL "Enable/disable support for TrackD" FORCE)
endif (NOT ENABLE_TRACKD_SUPPORT)

if (NOT ENABLE_VRPN_SUPPORT)
  set (ENABLE_VRPN_SUPPORT OFF
  	CACHE BOOL "Enable/disable support for VRPN" FORCE)
endif (NOT ENABLE_VRPN_SUPPORT)


###############################################################################
# Add local module path to CMAKE_MODULE_PATH
###############################################################################
set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} "${CMAKE_SOURCE_DIR}/cmake/Modules/")


###############################################################################
# include user-defined configuration
###############################################################################
include (${GOING_IMMERSIVE_SOURCE_DIR}/user.cmake)


###############################################################################
# find inVRs itself:
###############################################################################
find_package ( inVRs REQUIRED )
include_directories ( ${inVRs_INCLUDE_DIRS} )
link_directories ( ${inVRs_LIBRARY_DIRS} )
add_definitions ( ${inVRs_DEFINITIONS} )


###############################################################################
# add FRAMEWORK linker flags for MAC OSX systems
###############################################################################
foreach (framework ${inVRs_FRAMEWORKS} )
	set (CMAKE_SHARED_LINKER_FLAGS "${CMAKE_SHARED_LINKER_FLAGS} -framework ${framework}")
	set (CMAKE_SHARED_LINKER_FLAGS_RELEASE "${CMAKE_SHARED_LINKER_FLAGS_RELEASE} -framework ${framework}")
	set (CMAKE_SHARED_LINKER_FLAGS_DEBUG "${CMAKE_SHARED_LINKER_FLAGS_DEBUG} -framework ${framework}")
	set (CMAKE_EXE_LINKER_FLAGS "${CMAKE_EXE_LINKER_FLAGS} -framework ${framework}")
        set (CMAKE_EXE_LINKER_FLAGS_RELEASE "${CMAKE_EXE_LINKER_FLAGS_RELEASE} -framework ${framework}")
        set (CMAKE_EXE_LINKER_FLAGS_DEBUG "${CMAKE_EXE_LINKER_FLAGS_DEBUG} -framework ${framework}")
endforeach (framework ${inVRs_FRAMEWORKS} )


###############################################################################
# include platform-dependent compiler flags
###############################################################################
include (${CMAKE_SOURCE_DIR}/cmake/config_buildFlags.cmake)


###############################################################################
# update include directories for TrackD and VRPN (if support is activated)
###############################################################################
if (ENABLE_TRACKD_SUPPORT)
  include (${CMAKE_SOURCE_DIR}/cmake/findTrackD.cmake)
  include_directories (${TRACKD_INCLUDE_DIRS})
endif (ENABLE_TRACKD_SUPPORT)

if (ENABLE_VRPN_SUPPORT)
  include (${CMAKE_SOURCE_DIR}/cmake/findVRPN.cmake)
  include_directories (${VRPN_INCLUDE_DIRS})
endif (ENABLE_VRPN_SUPPORT)


###############################################################################
# Finish
###############################################################################
set (GOING_IMMERSIVE_CONFIG_CMAKE_LOADED ON)
endif (NOT GOING_IMMERSIVE_CONFIG_CMAKE_LOADED)
